%% FACS data analysis: scatter plots and histograms for oriTP amplification in liposomes.
% This program analyses FACS data for creating scatter plots and
% histograms.
% Steps for importing data:
    % Take the .fcs data from FACS instrument.
    % Import .fcs data into https://community.cytobank.org/
    % Filter the data accordingly (NO debris TX-red + NO debris dsGreen/YFP)
    % Export the filtered .fcs data as .txt files from https://community.cytobank.org/
        % Go to actions/export/export events/.txt file format/chose filter population to export/chose files to export/leave the channels as it is (all channels will be exported 
    % Save the .txt data in the same folder as this script is (the folder should also have importfile.m)

table{1}= importfile('+dNTPs_rep3_Specimen_004_B1_B01_003.fcs_file_internal_comp_No debris GFP.txt'); 
table{2}= importfile('-dNTPs_rep3_Specimen_004_B2_B02_004.fcs_file_internal_comp_No debris GFP.txt'); 

samples = ["+dNTPs", "-dNTPs"]

set(groot,{'DefaultAxesXColor','DefaultAxesYColor','DefaultAxesZColor','DefaultAxesLineWidth'},{'k','k','k',1})
%x = 1:100:10000000;
%y = (x).^2;

% defining the -dNTPs sample threshold
treshold2=mean((2*std(table{2}.PETexasRedA)-(table{2}.PETexasRedA)))


%Preparing the threshold line:
% AlexaFluor488=[]
% 
% for i=1:length(table{2}.PETexasRedA)
%     PET = table{2}.PETexasRedA(i) + 4000;
%     AlexaFluor488 = [AlexaFluor488; PET];
% end 


YFP2=[];

for c = 1:2;
    YFP = [] %Expressed population (change the table{#} depending on the population to analyze)
for i = 1:length(table{c}.AlexaFluor488A)
    if table{c}.PETexasRedA(i) > treshold2 && table{c}.AlexaFluor488A(i) > 0.6*(table{c}.PETexasRedA(i))
        %&& table{1}.PETexasRedA(i) < mean((table{2}.PETexasRedA)+(2*std(table{2}.PETexasRedA)))
        YFP = [YFP; table{c}.AlexaFluor488A(i)];
    end
end

Per_YFP = (length(YFP)/length(table{c}.AlexaFluor488A))*100; %percentage of YFP expressing liposomes.
Per_YFP = round(Per_YFP,2) %round the percentage to only 2 decimals 
str = '' + string(Per_YFP) + {'%'} %convert to string for it to appear in the scatter plot.

%Scatter plots from FACS
figure(c);
box on
set(gca,'FontSize',14);
h = get(gca, 'title');
set(h, 'FontSize',14)
%

% x=[10^2 10^6]
% y=x
% plot(x,y)
% hold on 
scatter(table{c}.PETexasRedA, table{c}.AlexaFluor488A,7,'filled','MarkerFaceColor','#0000FF');
hold on
plot(1:10^6,0.6*(1:10^6),'--k','LineWidth',1.5);
xline(treshold2,'--k','LineWidth',1.5,'label',str,'fontsize',12);

% b0 = 6000;
% b1 = 1;
% f = @(x) b1*x+b0;
% ezplot( f, 0, 1000000)

set(gca,'xscale','log')
set(gca,'yscale','log')

xlim([0 10^6])
ylim([0 10^6])
legend(samples(c),'background treshold','Location','NW','FontSize',12)
legend boxoff
xlabel('Membrane dye intensity (A.U)')
ylabel('dsGreen intensity (A.U)')
set(gca,'FontSize',14);
h = get(gca, 'title');
set(h, 'FontSize',14)
print(figure(c),'-dpng','-r1000','PF1 flow cytometry')

YFP_cell{c}=YFP;
Per_YFP_cell{c}=Per_YFP

end

% b0 = 6000;
% b1 = 1;
% f = @(x) b1*x+b0;
% ezplot( f, 0, 1000000)

% f3 = figure; 
% histogram(YFP_cell{1},'BinWidth',100,'facecolor','#FF0000','FaceAlpha',0.1,'EdgeAlpha',1,'Normalization','count');
% hold on
% histogram(YFP_cell{3},'BinWidth',100,'facecolor','#0000FF','FaceAlpha',0.1,'EdgeAlpha',1,'Normalization','count');
% histogram(YFP_cell{5},'BinWidth',100,'facecolor','#00FFFF','FaceAlpha',0.1,'EdgeAlpha',1,'Normalization','count');
% xline(mean((table{6}.AlexaFluor488A)+(4*std(table{6}.AlexaFluor488A))),'--k','LineWidth',2,'fontsize',20)
% set(gca,'yscale','log')
% xlim([-500 11e3])
% legend('oriYFP "all expresed','oriYFP "all purified"','oriYFP only','Water Background Treshold','Location','NE','FontSize',12)
% legend boxoff
% xlabel('YFP intensity ','FontSize',14);
% ylabel('Log(count)','FontSize',14);
% set(gca,'fontsize',14)
% print(f3,'-dpng','-r1000','PF3 Histogram')
